@@ -12,12 +12,12 @@ Launcher::Launcher(MainWindow *main)
 	setLayout(m_layout);
 
 	m_buttons[PASSWD_BUTTON] = new QPushButton(tr("Developer\nPassword"));
-	m_buttons[METHER_BUTTON] = new QPushButton(tr("Manage\nUsb"));
+	m_buttons[METHER_BUTTON] = new QPushButton(tr("Usb\nNetworking"));
 	m_buttons[XTERM_BUTTON] = new QPushButton(tr("Developer\nXTerm"));
 
 	//m_buttons[XTERM_BUTTON]->setEnabled(false);
-	m_layout->addWidget(m_buttons[PASSWD_BUTTON]);
 	m_layout->addWidget(m_buttons[METHER_BUTTON]);
+	m_layout->addWidget(m_buttons[PASSWD_BUTTON]);
 	m_layout->addWidget(m_buttons[XTERM_BUTTON]);
 
 	connect(m_buttons[PASSWD_BUTTON], SIGNAL(pressed()),
